@@ -27,12 +27,14 @@
 #' )
 #' ft
 #' @export
-#' @family functions to add rows in header or footer
+#' @family functions to add rows in a flextable
 #' @section Illustrations:
 #'
 #' \if{html}{\figure{fig_set_header_labels_1.png}{options: width="400"}}
 set_header_labels <- function(x, ..., values = NULL) {
-  if (!inherits(x, "flextable")) stop("set_header_labels supports only flextable objects.")
+  if (!inherits(x, "flextable")) {
+    stop(sprintf("Function `%s` supports only flextable objects.", "set_header_labels()"))
+  }
 
   if (is.null(values)) {
     values <- list(...)
@@ -64,7 +66,9 @@ set_header_labels <- function(x, ..., values = NULL) {
 #'
 #' \if{html}{\figure{fig_delete_part_1.png}{options: width="300"}}
 delete_part <- function(x, part = "header") {
-  if (!inherits(x, "flextable")) stop("delete_part supports only flextable objects.")
+  if (!inherits(x, "flextable")) {
+    stop(sprintf("Function `%s` supports only flextable objects.", "delete_part()"))
+  }
   part <- match.arg(part, c("body", "header", "footer"), several.ok = FALSE)
   nrow_ <- nrow(x[[part]]$dataset)
   x[[part]] <- complex_tabpart(
@@ -136,11 +140,11 @@ as_new_data <- function(x, ..., values = NULL) {
 #'
 #' ft <- theme_booktabs(ft)
 #' ft
-#' @family functions that add lines in the table
+#' @family functions to add rows in a flextable
 #' @seealso [flextable()]
 add_body <- function(x, top = TRUE, ..., values = NULL) {
   if (!inherits(x, "flextable")) {
-    stop("add_body supports only flextable objects.")
+    stop(sprintf("Function `%s` supports only flextable objects.", "add_body()"))
   }
 
   new_data <- as_new_data(x = x, ..., values = values)
@@ -188,13 +192,12 @@ add_body <- function(x, top = TRUE, ..., values = NULL) {
 #' ft_1 <- theme_booktabs(ft_1, bold_header = TRUE)
 #' ft_1 <- align(ft_1, align = "center", part = "all")
 #' ft_1
-#' @family functions that add lines in the table
-#' @family functions to add rows in header or footer
+#' @family functions to add rows in a flextable
 #' @section Illustrations:
 #' \if{html}{\figure{fig_add_header_1.png}{options: width="300"}}
 add_header <- function(x, top = TRUE, ..., values = NULL) {
   if (!inherits(x, "flextable")) {
-    stop("add_header supports only flextable objects.")
+    stop(sprintf("Function `%s` supports only flextable objects.", "add_header()"))
   }
 
   header_data <- as_new_data(x = x, ..., values = values)
@@ -235,13 +238,12 @@ add_header <- function(x, top = TRUE, ..., values = NULL) {
 #' )
 #' ft <- align(ft, part = "footer", align = "right", j = 1:4)
 #' ft
-#' @family functions that add lines in the table
-#' @family functions to add rows in header or footer
+#' @family functions to add rows in a flextable
 #' @section Illustrations:
 #' \if{html}{\figure{fig_add_footer_1.png}{options: width="300"}}
 add_footer <- function(x, top = TRUE, ..., values = NULL) {
   if (!inherits(x, "flextable")) {
-    stop("add_footer supports only flextable objects.")
+    stop(sprintf("Function `%s` supports only flextable objects.", "add_footer()"))
   }
 
   footer_data <- as_new_data(x = x, ..., values = values)
@@ -269,10 +271,15 @@ add_footer <- function(x, top = TRUE, ..., values = NULL) {
 #' number of labels is equal to the number of columns displayed.
 #'
 #' The function can add only one single row by call.
+#'
+#' Labels can also be formatted with [as_paragraph()].
+#'
 #' @param x a flextable object
 #' @param top should the row be inserted at the top or the bottom.
-#' @param values values to add. It can be a `list` or a `character()` vector.
-#' If it is a list, it must be a named list using the names of the columns of the
+#' @param values values to add. It can be a `list`, a `character()` vector
+#' or a call to [as_paragraph()].
+#'
+#' If it is a list, it can be a named list with the names of the columns of the
 #' original data.frame or the `colkeys`; this is the recommended method because
 #' it allows to keep the original data types and therefore allows to perform
 #' conditional formatting. If a character, columns of the original data.frame
@@ -284,35 +291,77 @@ add_footer <- function(x, top = TRUE, ..., values = NULL) {
 #' @param colwidths the number of columns to merge in the row for each label
 #'
 #' @examples
-#' ft <- flextable(head(iris))
-#' ft <- add_body_row(ft, values = list(1000), colwidths = 5)
-#' ft
-#' @family functions that add lines in the table
-#' @seealso [flextable()], [add_header_row()]
+#' library(flextable)
+#'
+#' ft01 <- fp_text_default(color = "red")
+#' ft02 <- fp_text_default(color = "orange")
+#'
+#' pars <- as_paragraph(
+#'   as_chunk(c("(1)", "(2)"), props = ft02), " ",
+#'   as_chunk(
+#'     c(
+#'       "My tailor is rich",
+#'       "My baker is rich"
+#'     ),
+#'     props = ft01
+#'   )
+#' )
+#'
+#' ft_1 <- flextable(head(mtcars))
+#' ft_1 <- add_body_row(ft_1,
+#'   values = pars,
+#'   colwidths = c(5, 6), top = FALSE
+#' )
+#' ft_1 <- add_body_row(ft_1,
+#'   values = pars,
+#'   colwidths = c(3, 8), top = TRUE
+#' )
+#' ft_1 <- theme_box(ft_1)
+#' ft_1
+#'
+#' ft_2 <- flextable(head(airquality))
+#' ft_2 <- add_body_row(ft_2,
+#'   values = c("blah", "bleeeh"),
+#'   colwidths = c(4, 2), top = TRUE
+#' )
+#' ft_2 <- theme_box(ft_2)
+#' ft_2
+#' @family functions to add rows in a flextable
+#' @seealso [flextable()], [set_caption()]
 add_body_row <- function(x, top = TRUE, values = list(), colwidths = integer(0)) {
   if (!inherits(x, "flextable")) {
-    stop("add_body_row supports only flextable objects.")
+    stop(sprintf("Function `%s` supports only flextable objects.", "add_body_row()"))
   }
 
-  if (!is.list(values)) stop("values must be a list.")
-
   if (length(colwidths) < 1) {
     colwidths <- rep(1L, length(x$col_keys))
   }
 
   if (sum(colwidths) != length(x$col_keys)) {
-    stop("colwidths' sum must be equal to the number of col_keys (", length(x$col_keys), ")")
+    stop(sprintf(
+      "sum of colwidths elements must be equal to the number of col_keys: %.0f.",
+      length(x$col_keys)))
+  }
+  if (is.atomic(values)) {
+    values <- as.list(values)
   }
 
-  if (any(sapply(values, length) > 1)) {
-    stop("argument 'values' is expected to be made of elements of length 1")
+  row_span <- unlist(lapply(colwidths, function(x) {
+    z <- integer(x)
+    z[1] <- x
+    z
+  }))
+  col_j <- which(row_span>0)
+
+  body_data <- x$body$dataset[nrow(x$body$dataset) + 1, ]
+
+  if (inherits(values, "paragraph")) {
+  } else if (!is.null(attr(values, "names"))) {
+    body_data[, names(values)] <- values
+  } else {
+    body_data[, which(row_span>0)] <- values
   }
 
-  values_ <- inverse.rle(structure(list(lengths = colwidths, values = values), class = "rle"))
-
-  names(values_) <- x$col_keys
-  body_data <- as.data.frame(values_, check.names = FALSE, stringsAsFactors = FALSE)
-
   if (nrow_part(x, "body") < 1) {
     x$body <- complex_tabpart(
       data = body_data, col_keys = x$col_keys,
@@ -322,14 +371,15 @@ add_body_row <- function(x, top = TRUE, values = list(), colwidths = integer(0))
     x$body <- add_rows(x$body, body_data, first = top)
   }
 
-  row_span <- unlist(lapply(colwidths, function(x) {
-    z <- integer(x)
-    z[1] <- x
-    z
-  }))
-  i <- ifelse(top, 1, nrow(x$body$dataset))
+  i <- ifelse(top, 1, nrow_part(x, "body"))
   x$body$spans$rows[i, ] <- row_span
 
+  if (inherits(values, "paragraph")) {
+    for(j in seq_along(col_j)) {
+      x <- mk_par(x, i = i, j = col_j[j], value = values[j], part = "body")
+    }
+  }
+
   x
 }
 
@@ -346,29 +396,44 @@ add_body_row <- function(x, top = TRUE, values = list(), colwidths = integer(0))
 #'
 #' The function can add only one single row by call.
 #'
+#' Labels can also be formatted with [as_paragraph()].
+#'
 #' @param x a flextable object
 #' @param top should the row be inserted at the
 #' top or the bottom. Default to TRUE.
 #' @param values values to add, a character vector (as header rows
-#' contains only character values/columns) or a list.
+#' contains only character values/columns), a list
+#' or a call to [as_paragraph()].
 #' @param colwidths the number of columns used for each label
 #' @examples
-#' ft_1 <- flextable(head(iris))
-#' ft_1 <- add_header_row(ft_1,
-#'   values = "blah blah", colwidths = 5
-#' )
-#' ft_1 <- add_header_row(ft_1,
-#'   values = c("blah", "blah"),
-#'   colwidths = c(3, 2)
+#' library(flextable)
+#'
+#' ft01 <- fp_text_default(color = "red")
+#' ft02 <- fp_text_default(color = "orange")
+#'
+#' pars <- as_paragraph(
+#'   as_chunk(c("(1)", "(2)"), props = ft02), " ",
+#'   as_chunk(c("My tailor is rich",
+#'     "My baker is rich"), props = ft01)
 #' )
+#'
+#' ft_1 <- flextable(head(mtcars))
+#' ft_1 <- add_header_row(ft_1, values = pars,
+#'   colwidths = c(5, 6), top = FALSE)
+#' ft_1 <- add_header_row(ft_1, values = pars,
+#'   colwidths = c(3, 8), top = TRUE)
 #' ft_1
-#' @family functions that add lines in the table
-#' @family functions to add rows in header or footer
-#' @section Illustrations:
-#' \if{html}{\figure{fig_add_header_row_1.png}{options: width="300"}}
+#'
+#' ft_2 <- flextable(head(airquality))
+#' ft_2 <- add_header_row(ft_2, values = c("Measure", "Time"),
+#'   colwidths = c(4, 2), top = TRUE)
+#' ft_2 <- theme_box(ft_2)
+#' ft_2
+#' @family functions to add rows in a flextable
+#' @seealso [flextable()], [set_caption()]
 add_header_row <- function(x, top = TRUE, values = character(0), colwidths = integer(0)) {
   if (!inherits(x, "flextable")) {
-    stop("add_header_row supports only flextable objects.")
+    stop(sprintf("Function `%s` supports only flextable objects.", "add_header_row()"))
   }
 
   if (length(colwidths) < 1) {
@@ -376,19 +441,17 @@ add_header_row <- function(x, top = TRUE, values = character(0), colwidths = int
   }
 
   if (sum(colwidths) != length(x$col_keys)) {
-    stop("colwidths'sum must be equal to the number of col_keys (", length(x$col_keys), ")")
-  }
-  if (is.list(values)) {
-    values <- as.character(unlist(values))
-  } else if (!is.atomic(values)) {
-    stop("'values' must be an atomic vector or a list.")
+    stop(sprintf(
+      "sum of colwidths elements must be equal to the number of col_keys: %.0f.",
+      length(x$col_keys)))
   }
 
-  values_ <- inverse.rle(structure(list(lengths = colwidths, values = values), class = "rle"))
-  values_ <- as.list(values_)
-
-  names(values_) <- x$col_keys
-  header_data <- as.data.frame(values_, check.names = FALSE, stringsAsFactors = FALSE)
+  if (inherits(values, "paragraph")) {
+    str_values <- vapply(values, function(x) paste0(x$txt, collapse = ""), FUN.VALUE = "")
+  } else {
+    str_values <- values
+  }
+  header_data <- data_from_char(values = str_values, colwidths = colwidths, col_keys = x$col_keys)
 
   if (nrow_part(x, "header") < 1) {
     x$header <- complex_tabpart(data = header_data, col_keys = x$col_keys, cwidth = dim(x)$widths, cheight = .25)
@@ -396,7 +459,6 @@ add_header_row <- function(x, top = TRUE, values = character(0), colwidths = int
     x$header <- add_rows(x$header, header_data, first = top)
   }
 
-
   row_span <- unlist(lapply(colwidths, function(x) {
     z <- integer(x)
     z[1] <- x
@@ -405,9 +467,22 @@ add_header_row <- function(x, top = TRUE, values = character(0), colwidths = int
   i <- ifelse(top, 1, nrow(x$header$dataset))
   x$header$spans$rows[i, ] <- row_span
 
+  if (inherits(values, "paragraph")) {
+
+    if(top) i <- 1
+    else i <- nrow_part(x, "header")
+
+    col_j <- which(row_span>0)
+
+    for(j in seq_along(col_j)) {
+      x <- mk_par(x, i = i, j = col_j[j], value = values[j], part = "header")
+    }
+  }
+
   x
 }
 
+
 #' @export
 #' @title Add footer labels
 #'
@@ -420,41 +495,65 @@ add_header_row <- function(x, top = TRUE, values = character(0), colwidths = int
 #' number of labels is equal to the number of columns displayed.
 #'
 #' The function can add only one single row by call.
+#'
+#' Labels can be formatted with [as_paragraph()].
 #' @inheritParams add_body_row
-#' @family functions that add lines in the table
-#' @family functions to add rows in header or footer
+#' @family functions to add rows in a flextable
+#' @seealso [flextable()], [set_caption()]
 #' @examples
-#' ft_1 <- flextable(head(iris))
+#' library(flextable)
+#'
+#' ft01 <- fp_text_default(color = "red")
+#' ft02 <- fp_text_default(color = "orange")
+#'
+#' pars <- as_paragraph(
+#'   as_chunk(c("(1)", "(2)"), props = ft02), " ",
+#'   as_chunk(
+#'     c(
+#'       "My tailor is rich",
+#'       "My baker is rich"
+#'     ),
+#'     props = ft01
+#'   )
+#' )
+#'
+#' ft_1 <- flextable(head(mtcars))
 #' ft_1 <- add_footer_row(ft_1,
-#'   values = "blah blah", colwidths = 5
+#'   values = pars,
+#'   colwidths = c(5, 6), top = FALSE
 #' )
 #' ft_1 <- add_footer_row(ft_1,
-#'   values = c("blah", "blah"),
-#'   colwidths = c(3, 2)
+#'   values = pars,
+#'   colwidths = c(3, 8), top = TRUE
 #' )
 #' ft_1
-#' @section Illustrations:
-#' \if{html}{\figure{fig_add_footer_row_1.png}{options: width="300"}}
+#'
+#' ft_2 <- flextable(head(airquality))
+#' ft_2 <- add_footer_row(ft_2,
+#'   values = c("Measure", "Time"),
+#'   colwidths = c(4, 2), top = TRUE
+#' )
+#' ft_2 <- theme_box(ft_2)
+#' ft_2
 add_footer_row <- function(x, top = TRUE, values = character(0), colwidths = integer(0)) {
   if (!inherits(x, "flextable")) {
-    stop("add_footer_row supports only flextable objects.")
+    stop(sprintf("Function `%s` supports only flextable objects.", "add_footer_row()"))
   }
 
   if (sum(colwidths) != length(x$col_keys)) {
-    stop("colwidths' sum must be equal to the number of col_keys (", length(x$col_keys), ")")
+    stop(sprintf("`colwidths` argument specify room for %.0f columns but %.0f are expected.",
+                 sum(colwidths), length(x$col_keys)))
   }
   if (is.atomic(values)) {
     values <- as.list(values)
   }
 
-  if (!is.list(values)) stop("values must be a list.")
-
-  values_ <- inverse.rle(structure(list(lengths = colwidths, values = values), class = "rle"))
-  values_ <- as.list(values_)
-
-  names(values_) <- x$col_keys
-
-  footer_data <- as.data.frame(values_, check.names = FALSE, stringsAsFactors = FALSE)
+  if (inherits(values, "paragraph")) {
+    str_values <- vapply(values, function(x) paste0(x$txt, collapse = ""), FUN.VALUE = "")
+  } else {
+    str_values <- values
+  }
+  footer_data <- data_from_char(values = str_values, colwidths = colwidths, col_keys = x$col_keys)
 
   if (nrow_part(x, "footer") < 1) {
     x$footer <- complex_tabpart(data = footer_data, col_keys = x$col_keys, cwidth = dim(x)$widths, cheight = .25)
@@ -467,12 +566,34 @@ add_footer_row <- function(x, top = TRUE, values = character(0), colwidths = int
     z[1] <- x
     z
   }))
-  i <- ifelse(top, 1, nrow(x$footer$dataset))
+  i <- ifelse(top, 1, nrow_part(x, "footer"))
   x$footer$spans$rows[i, ] <- row_span
+  col_j <- which(row_span>0)
+
+  if (inherits(values, "paragraph")) {
+    for(j in seq_along(col_j)) {
+      x <- mk_par(x, i = i, j = col_j[j], value = values[j], part = "footer")
+    }
+  }
 
   x
 }
 
+data_from_char <- function(values, colwidths, col_keys) {
+
+  if (is.list(values)) {
+    values <- as.character(unlist(values))
+  } else if (!is.atomic(values)) {
+    stop("'values' must be an atomic vector or a list.")
+  }
+
+  values_ <- inverse.rle(structure(list(lengths = colwidths, values = values), class = "rle"))
+  values_ <- as.list(values_)
+
+  names(values_) <- col_keys
+  as.data.frame(values_, check.names = FALSE, stringsAsFactors = FALSE)
+}
+
 # add labels as spanned rows ----
 
 #' @export
@@ -486,28 +607,60 @@ add_footer_row <- function(x, top = TRUE, values = character(0), colwidths = int
 #' be used to adding titles on the top rows of the flextable.
 #'
 #' @param x a `flextable` object
-#' @param values a character vector, each element will
+#' @param values a character vector or a call to [as_paragraph()]
+#' to get formated content, each element will
 #' be added as a new row.
 #' @param top should the row be inserted at the top
 #' or the bottom. Default to TRUE.
 #' @family functions that add rows in the table
-#' @family functions to add rows in header or footer
 #' @section Illustrations:
 #' \if{html}{\figure{fig_add_header_lines_1.png}{options: width="300"}}
 #' @examples
+#' # ex 1----
 #' ft_1 <- flextable(head(iris))
 #' ft_1 <- add_header_lines(ft_1, values = "blah blah")
 #' ft_1 <- add_header_lines(ft_1, values = c("blah 1", "blah 2"))
 #' ft_1 <- autofit(ft_1)
 #' ft_1
+#'
+#' # ex 2----
+#' ft01 <- fp_text_default(color = "red")
+#' ft02 <- fp_text_default(color = "orange")
+#' ref <- c("(1)", "(2)")
+#' pars <- as_paragraph(
+#'   as_chunk(ref, props = ft02), " ",
+#'   as_chunk(rep("My tailor is rich", length(ref)), props = ft01)
+#' )
+#'
+#' ft_2 <- flextable(head(mtcars))
+#' ft_2 <- add_header_lines(ft_2, values = pars, top = FALSE)
+#' ft_2 <- add_header_lines(ft_2, values = ref, top = TRUE)
+#' ft_2 <- add_footer_lines(ft_2, values = "blah", top = TRUE)
+#' ft_2 <- add_footer_lines(ft_2, values = pars, top = TRUE)
+#' ft_2 <- add_footer_lines(ft_2, values = ref, top = FALSE)
+#' ft_2 <- autofit(ft_2)
+#' ft_2
 add_header_lines <- function(x, values = character(0), top = TRUE) {
   if (!inherits(x, "flextable")) {
-    stop("add_header_lines supports only flextable objects.")
+    stop(sprintf("Function `%s` supports only flextable objects.", "add_header_lines()"))
+  }
+  values_map <- values
+  if (top) values_map <- rev(values_map)
+
+  if(inherits(values, "paragraph")) {
+    for (ivalue in seq_len(length(values_map))) {
+      x <- add_header_row(x, values = "", colwidths = length(x$col_keys), top = top)
+      if(top) i <- 1
+      else i <- nrow_part(x, "header")
+      x <- mk_par(x, i = i, j = 1, value = values_map[ivalue], part = "header")
+    }
+  } else {
+    for (value in values_map) {
+      x <- add_header_row(x, values = value, colwidths = length(x$col_keys), top = top)
+    }
   }
 
-  for (value in values) {
-    x <- add_header_row(x, values = value, colwidths = length(x$col_keys), top = top)
-  }
+
   x
 }
 
@@ -521,8 +674,7 @@ add_header_lines <- function(x, values = character(0), top = TRUE) {
 #' This is a sugar function to be used when you need to
 #' add labels in the footer, a footnote for example.
 #' @inheritParams add_header_lines
-#' @family functions that add lines in the table
-#' @family functions to add rows in header or footer
+#' @family functions to add rows in a flextable
 #' @section Illustrations:
 #' \if{html}{\figure{fig_add_footer_lines_1.png}{options: width="300"}}
 #' @examples
@@ -533,12 +685,28 @@ add_header_lines <- function(x, values = character(0), top = TRUE) {
 #' ft_1
 add_footer_lines <- function(x, values = character(0), top = FALSE) {
   if (!inherits(x, "flextable")) {
-    stop("add_footer_lines supports only flextable objects.")
+    stop(sprintf("Function `%s` supports only flextable objects.", "add_footer_lines()"))
   }
 
-  for (value in values) {
-    x <- add_footer_row(x, values = value, colwidths = length(x$col_keys), top = top)
+  ivalues <- seq_len(length(values))
+  if (top) {
+    ivalues <- rev(ivalues)
   }
+
+  if(inherits(values, "paragraph")) {
+    for (ivalue in ivalues) {
+      x <- add_footer_row(x, values = "", colwidths = length(x$col_keys), top = top)
+      if(top) i <- 1
+      else i <- nrow_part(x, "footer")
+      x <- mk_par(x, i = i, j = 1, value = values[ivalue], part = "footer")
+    }
+  } else {
+    for (ivalue in ivalues) {
+      x <- add_footer_row(x, values = values[ivalue],
+                          colwidths = length(x$col_keys), top = top)
+    }
+  }
+
   x
 }
 
@@ -624,14 +792,17 @@ set_part_df <- function(x, mapping = NULL, key = "col_keys", part) {
 #' ft_1 <- theme_vanilla(ft_1)
 #' ft_1 <- fix_border_issues(ft_1)
 #' ft_1
-#' @family functions to add rows in header or footer
+#' @family functions to add rows in a flextable
 #' @section Illustrations:
 #'
 #' \if{html}{\figure{fig_set_header_footer_df_1.png}{options: width="400"}}
 #'
 #' \if{html}{\figure{fig_set_header_footer_df_2.png}{options: width="400"}}
 set_header_df <- function(x, mapping = NULL, key = "col_keys") {
-  if (!inherits(x, "flextable")) stop("set_header_labels supports only flextable objects.")
+  if (!inherits(x, "flextable")) {
+    stop(sprintf("Function `%s` supports only flextable objects.", "set_header_df()"))
+  }
+
   set_part_df(x, mapping = mapping, key = key, part = "header")
 }
 
@@ -654,7 +825,10 @@ set_header_df <- function(x, mapping = NULL, key = "col_keys") {
 #' ft_2 <- fix_border_issues(ft_2)
 #' ft_2
 set_footer_df <- function(x, mapping = NULL, key = "col_keys") {
-  if (!inherits(x, "flextable")) stop("set_header_labels supports only flextable objects.")
+  if (!inherits(x, "flextable")) {
+    stop(sprintf("Function `%s` supports only flextable objects.", "set_footer_df()"))
+  }
+
   set_part_df(x, mapping = mapping, key = key, part = "footer")
 }
 
@@ -684,7 +858,7 @@ set_footer_df <- function(x, mapping = NULL, key = "col_keys") {
 #' to use for splitting.
 #' @param fixed logical. If TRUE match `split` exactly,
 #' otherwise use regular expressions.
-#' @family functions to add rows in header or footer
+#' @family functions to add rows in a flextable
 #' @section Illustrations:
 #'
 #' \if{html}{\figure{fig_separate_header_1.png}{options: width="500"}}
@@ -719,11 +893,7 @@ separate_header <- function(x,
                             split = "[_\\.]",
                             fixed = FALSE) {
   if (nrow_part(x, "header") > 1) {
-    stop(
-      "the flextable object already have additional row(s),",
-      " run `separate_header()` before any header row",
-      " augmentation"
-    )
+    stop("the flextable object already have additional row(s),\nrun `separate_header()` before any header row augmentation")
   }
 
   ref_list <- tstrsplit(x$col_keys, split = split, fill = "", fixed = fixed)
