@@ -2,10 +2,19 @@
 #' @export
 #' @title image chunk wrapper
 #' @description The function lets add images within flextable
-#' objects with function [compose()].
-#' It should be used inside a call to [as_paragraph()].
+#' objects with functions:
+#' - [compose()] and [as_paragraph()],
+#' - [append_chunks()],
+#' - [prepend_chunks()]
 #' @param src image filename
-#' @param width,height size of the png file in inches
+#' @param width,height size of the image file. It can be ignored
+#' if parameter `guess_size=TRUE`, see parameter `guess_size`.
+#' @param guess_size If package 'magick' is installed, this option
+#' can be used (set it to `TRUE` and don't provide values for paramters
+#' `width` and `height`). When the flextable will be printed,
+#' the images will be read and width and height will be guessed. This
+#' should be avoid if possible as it can be an extensive task when
+#' several images.
 #' @param unit unit for width and height, one of "in", "cm", "mm".
 #' @param ... unused argument
 #' @family chunk elements for paragraph
@@ -17,25 +26,25 @@
 #' are removed when outputing to PowerPoint format.
 #' @seealso [compose()], [as_paragraph()]
 #' @examples
-#' img.file <- file.path( R.home("doc"), "html", "logo.jpg" )
-#' library(officer)
-#'
-#' myft <- flextable( head(iris))
-#'
-#' myft <- compose( myft, i = 1:3, j = 1,
-#'  value = as_paragraph(
-#'    as_image(src = img.file, width = .20, height = .15),
-#'    " blah blah ",
-#'    as_chunk(Sepal.Length, props = fp_text(color = "red"))
-#'  ),
-#'  part = "body")
-#'
-#' ft <- autofit(myft)
-#' ft
+#' img.file <- file.path( R.home("doc"),
+#'   "html", "logo.jpg" )
+#' if (require("magick")) {
+#'   myft <- flextable( head(iris))
+#'   myft <- compose( myft, i = 1:3, j = 1,
+#'    value = as_paragraph(
+#'      as_image(src = img.file),
+#'      " ",
+#'      as_chunk(Sepal.Length,
+#'        props = fp_text_default(color = "red"))
+#'    ),
+#'    part = "body")
+#'   ft <- autofit(myft)
+#'   ft
+#' }
 #' @section Illustrations:
 #'
 #' \if{html}{\figure{fig_as_image_1.png}{options: width="400"}}
-as_image <- function(src, width = .5, height = .2, unit = "in", ...) {
+as_image <- function(src, width = NULL, height = NULL, unit = "in", guess_size = TRUE, ...) {
 
   width <- convin(unit = unit, x = width)
   height <- convin(unit = unit, x = height)
@@ -45,6 +54,20 @@ as_image <- function(src, width = .5, height = .2, unit = "in", ...) {
     if( length(height) == 1 ) height <- rep(height, length(src))
   }
 
+  if (guess_size && (is.null(width) || is.null(height))) {
+    if (!requireNamespace("magick", quietly = TRUE)) {
+      stop("package magick is required when using `guess_size` option.")
+    }
+    sizes <- lapply(src, function(x) {
+      z <- magick::image_read(x)
+      z <- magick::image_data(z)
+      attr(z, "dim")[-1]
+    })
+    sizes <- do.call(rbind, sizes)
+    width <- sizes[,1] / 72
+    height <- sizes[,2] / 72
+  }
+
   data <- chunk_dataframe(width = as.double(width),
                           height = as.double(height),
                           img_data = src
@@ -57,8 +80,10 @@ as_image <- function(src, width = .5, height = .2, unit = "in", ...) {
 #' @export
 #' @title mini barplots chunk wrapper
 #' @description This function is used to insert bars into
-#' flextable with function [compose()].
-#' It should be used inside a call to [as_paragraph()]
+#' flextable with functions:
+#' - [compose()] and [as_paragraph()],
+#' - [append_chunks()],
+#' - [prepend_chunks()].
 #' @param value values containing the bar size
 #' @param max max bar size
 #' @param barcol bar color
@@ -131,8 +156,10 @@ minibar <- function(value, max = NULL, barcol = "#CCCCCC", bg = "transparent", w
 #' @export
 #' @title mini linerange chunk wrapper
 #' @description This function is used to insert lineranges into
-#' flextable with function [compose()].
-#' It should be used inside a call to [as_paragraph()]
+#' flextable with functions:
+#' - [compose()] and [as_paragraph()],
+#' - [append_chunks()],
+#' - [prepend_chunks()].
 #' @param value values containing the bar size
 #' @param min min bar size. Default min of value
 #' @param max max bar size. Default max of value
@@ -221,8 +248,10 @@ linerange <- function(value, min = NULL, max = NULL, rangecol = "#CCCCCC",
 #' @export
 #' @title mini lollipop chart chunk wrapper
 #' @description This function is used to insert lollipop charts into
-#' flextable with function [compose()].
-#' It should be used inside a call to [as_paragraph()]
+#' flextable with functions:
+#' - [compose()] and [as_paragraph()],
+#' - [append_chunks()],
+#' - [prepend_chunks()].
 #' @param value values containing the bar size
 #' @param min min bar size. Default min of value
 #' @param max max bar size. Default max of value
@@ -346,8 +375,10 @@ lollipop <- function(value, min = NULL, max = NULL, rangecol = "#CCCCCC",
 #' @export
 #' @title mini plots chunk wrapper
 #' @description This function is used to insert mini plots into
-#' flextable with function [compose()].
-#' It should be used inside a call to [as_paragraph()].
+#' flextable with functions:
+#' - [compose()] and [as_paragraph()],
+#' - [append_chunks()],
+#' - [prepend_chunks()].
 #'
 #' Available plots are 'box', 'line', 'points', 'density'.
 #' @param value a numeric vector, stored in a list column.
@@ -455,14 +486,18 @@ plot_chunk <- function(value, width = 1, height = .2,
 
 
 #' @export
-#' @title gg plots chunk wrapper
+#' @title ggplots chunk wrapper
 #' @description This function is used to insert mini gg plots into
-#' flextable with function [compose()].
-#' It should be used inside a call to [as_paragraph()].
+#' flextable with functions:
+#' - [compose()] and [as_paragraph()],
+#' - [append_chunks()],
+#' - [prepend_chunks()].
 #'
-#' @param value gg objects, stored in a list column.
-#' @param width,height size of the resulting png file in inches
+#' @param value gg objects, stored in a list column; or a list
+#' of 'ggplot' objects.
+#' @param width,height size of the resulting png file.
 #' @param unit unit for width and height, one of "in", "cm", "mm".
+#' @param res resolution of the png image in ppi
 #' @note
 #' This chunk option requires package officedown in a R Markdown
 #' context with Word output format.
@@ -499,7 +534,7 @@ plot_chunk <- function(value, width = 1, height = .2,
 #' @section Illustrations:
 #'
 #' \if{html}{\figure{fig_gg_chunk_1.png}{options: width="200"}}
-gg_chunk <- function(value, width = 1, height = .2, unit = "in") {
+gg_chunk <- function(value, width = 1, height = .2, unit = "in", res = 300) {
 
   width <- convin(unit = unit, x = width)
   height <- convin(unit = unit, x = height)
@@ -510,7 +545,7 @@ gg_chunk <- function(value, width = 1, height = .2, unit = "in") {
   files <- mapply(function(x, width, height){
     file <- tempfile(fileext = ".png")
     png(filename = file, width = width, height = height,
-        units = "in", bg = "transparent", res = 300)
+        units = "in", bg = "transparent", res = res)
       print(x)
     dev.off()
     file
@@ -524,3 +559,73 @@ gg_chunk <- function(value, width = 1, height = .2, unit = "in") {
   class(z) <- c("img_chunk", class(z))
   z
 }
+
+#' @export
+#' @title 'Grid Graphics' chunk wrapper
+#' @description This function is used to insert grid objects into
+#' flextable with functions:
+#' - [compose()] and [as_paragraph()],
+#' - [append_chunks()],
+#' - [prepend_chunks()].
+#'
+#' @param value grid objects, stored in a list column; or a list
+#' of grid objects.
+#' @param width,height size of the resulting png file
+#' @param unit unit for width and height, one of "in", "cm", "mm".
+#' @param res resolution of the png image in ppi
+#' @note
+#' This chunk option requires package officedown in a R Markdown
+#' context with Word output format.
+#'
+#' PowerPoint cannot mix images and text in a paragraph, images
+#' are removed when outputing to PowerPoint format.
+#' @family chunk elements for paragraph
+#' @examples
+#' library(flextable)
+#' ft_1 <- flextable(head(cars))
+#' if(require("grid")){
+#'   ft_1 <- prepend_chunks(
+#'     x = ft_1, i = 2, j = 2,
+#'     grid_chunk(
+#'       list(
+#'         grid.circle(gp = gpar(fill="#ec11c2",
+#'           col = "transparent"))),
+#'       width = .15, height = .15)
+#'   )
+#' }
+#' ft_1
+grid_chunk <- function(value, width = 1, height = .2, unit = "in", res = 300) {
+
+  if (!requireNamespace("grid", quietly = TRUE)) {
+    stop(sprintf(
+      "'%s' package should be installed to create a flextable from an object of type '%s'.",
+      "grid", "grid")
+    )
+  }
+
+  width <- convin(unit = unit, x = width)
+  height <- convin(unit = unit, x = height)
+
+  width <- as.double(rep(width, length(value)))
+  height <- as.double(rep(height, length(value)))
+
+  files <- mapply(function(x, width, height){
+    file <- tempfile(fileext = ".png")
+    png(filename = file, width = width, height = height,
+        units = "in", bg = "transparent", res = res)
+    grid::grid.draw(x)
+    dev.off()
+    file
+  }, x = value,
+  width = width, height = height,
+  SIMPLIFY = FALSE)
+
+  files <- as.character(unlist(files))
+
+  z <- chunk_dataframe(width = width, height = height, img_data = files )
+  class(z) <- c("img_chunk", class(z))
+  z
+}
+
+
+
